@@ -8,6 +8,7 @@ from typing import (
     ClassVar,
     Dict,
     Iterator,
+    Mapping,
     NamedTuple,
     Set,
     Type,
@@ -23,13 +24,8 @@ from ._group import SignalGroup
 from ._group_descriptor import _check_field_equality, _pick_equality_operator
 from ._signal import Signal
 
-NULL = object()
-ALLOW_PROPERTY_SETTERS = "allow_property_setters"
-FIELD_DEPENDENCIES = "field_dependencies"
-GUESS_PROPERTY_DEPENDENCIES = "guess_property_dependencies"
 PYDANTIC_V1 = pydantic.version.VERSION.startswith("1")
 
-
 if TYPE_CHECKING:
     from inspect import Signature
 
@@ -38,7 +34,7 @@ if TYPE_CHECKING:
     from pydantic._internal import _utils as utils
     from typing_extensions import dataclass_transform as dataclass_transform  # py311
 
-    from ._signal import SignalInstance
+    from ._signal import RecursionMode, SignalInstance
 
     EqOperator = Callable[[Any, Any], bool]
 else:
@@ -58,6 +54,14 @@ else:
             return lambda a: a
 
 
+NULL = object()
+ALLOW_PROPERTY_SETTERS = "allow_property_setters"
+FIELD_DEPENDENCIES = "field_dependencies"
+GUESS_PROPERTY_DEPENDENCIES = "guess_property_dependencies"
+RECURSION_MODE = "recursion_mode"
+DEFAULT_RECURSION_MODE: "RecursionMode" = "deferred"
+
+
 @contextmanager
 def no_class_attributes() -> Iterator[None]:  # pragma: no cover
     """Context in which pydantic_main.ClassAttribute just passes value 2.
@@ -213,10 +217,31 @@ class EventedMetaclass(pydantic_main.ModelMetaclass):
         model_fields = _get_fields(cls)
         model_config = _get_config(cls)
 
+        recursion_cfg = model_config.get(RECURSION_MODE, {})
+        default_recursion: RecursionMode = DEFAULT_RECURSION_MODE
+        recursion_map: Mapping[str, RecursionMode] = {}
+        if isinstance(recursion_cfg, str):
+            if recursion_cfg not in {"immediate", "deferred"}:
+                raise ValueError(
+                    f"Invalid recursion mode {default_recursion!r}. Must be "
+                    "either 'immediate' or 'deferred'"
+                )
+            default_recursion = recursion_cfg
+        else:
+            if not isinstance(recursion_cfg, Mapping) or not all(
+                x in {"immediate", "deferred"} for x in recursion_cfg.values()
+            ):
+                raise ValueError(
+                    f"Invalid recursion mode {recursion_cfg!r}. Must be a mapping "
+                    "of field names to 'immediate' or 'deferred'."
+                )
+            recursion_map = recursion_cfg
+
         for n, f in model_fields.items():
             cls.__eq_operators__[n] = _pick_equality_operator(f.annotation)
             if not f.frozen:
-                signals[n] = Signal(f.annotation)
+                recursion = recursion_map.get(n, default_recursion)
+                signals[n] = Signal(f.annotation, recursion_mode=recursion)
 
             # If a field type has a _json_encode method, add it to the json
             # encoders for this model.
@@ -244,7 +269,8 @@ class EventedMetaclass(pydantic_main.ModelMetaclass):
             for key, attr in namespace.items():
                 if isinstance(attr, property) and attr.fset is not None:
                     cls.__property_setters__[key] = attr
-                    signals[key] = Signal(object)
+                    recursion = recursion_map.get(key, default_recursion)
+                    signals[key] = Signal(object, recursion_mode=recursion)
         else:
             for b in cls.__bases__:
                 with suppress(AttributeError):
