@@ -5,7 +5,6 @@ from unittest.mock import Mock
 from weakref import ref
 
 import pytest
-import toolz
 
 from psygnal._weak_callback import WeakCallback, weak_callback
 
@@ -59,6 +58,7 @@ def test_slot_types(type_: str, capsys) -> None:
 
         cb = weak_callback(obj, strong_func=(type_ == "function"), finalize=final_mock)
     elif type_ == "toolz_function":
+        toolz = pytest.importorskip("toolz")
 
         @toolz.curry
         def obj(z: int, x: int) -> None:
@@ -73,6 +73,7 @@ def test_slot_types(type_: str, capsys) -> None:
     elif type_ == "partial_method":
         cb = weak_callback(partial(obj.method, 2), max_args=0, finalize=final_mock)
     elif type_ == "toolz_method":
+        toolz = pytest.importorskip("toolz")
         cb = weak_callback(toolz.curry(obj.method, 2), max_args=0, finalize=final_mock)
     elif type_ == "mock":
         cb = weak_callback(mock, finalize=final_mock)
@@ -114,8 +115,7 @@ def test_weak_callable_equality() -> None:
     """Slot callers should be equal only if they represent the same bound-method."""
 
     class T:
-        def x(self):
-            ...
+        def x(self): ...
 
     t1 = T()
     t2 = T()
@@ -150,8 +150,7 @@ def test_nonreferencable() -> None:
     class T:
         __slots__ = ("x",)
 
-        def method(self) -> None:
-            ...
+        def method(self) -> None: ...
 
     t = T()
     with pytest.warns(UserWarning, match="failed to create weakref"):
@@ -167,8 +166,7 @@ def test_nonreferencable() -> None:
 
 @pytest.mark.parametrize("strong", [True, False])
 def test_deref(strong: bool) -> None:
-    def func(x):
-        ...
+    def func(x): ...
 
     p = partial(func, 1)
     cb = weak_callback(p, strong_func=strong)
